==> ejc-assistrmat-impl-3.0.0-20220929.123619-241-sources.jar: com/ejianc/business/assist/rmat/service/IRmatFlowService.java <==
package com.ejianc.business.assist.rmat.service;

import com.ejianc.business.assist.rmat.bean.*;
import com.ejianc.business.assist.rmat.vo.RmatFlowVO;
import com.ejianc.business.outrmat.delivery.bean.OutRmatDeliveryEntity;
import com.ejianc.business.outrmat.lose.bean.OutRmatLoseEntity;
import com.ejianc.business.outrmat.restitute.bean.OutRmatRestituteEntity;
import com.ejianc.business.outrmat.start.bean.OutRmatStartEntity;
import com.ejianc.business.outrmat.stop.bean.OutRmatStopEntity;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.util.List;

/**
 * 租赁流水表
 * 
 * @author generator
 * 
 */
public interface IRmatFlowService extends IBaseService<RmatFlowEntity> {

    Boolean insertFlow(List<RmatFlowVO> vos);

    Boolean insertCheckFlow(CheckEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertCheckFlow(OutRmatDeliveryEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertStopFlow(StopEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertStopFlow(OutRmatStopEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertStartFlow(StartEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertStartFlow(OutRmatStartEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertRestFlow(RestituteEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertRestFlow(OutRmatRestituteEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertLoseFlow(LoseEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertLoseFlow(OutRmatLoseEntity entity, String billTypeCode, Integer effectiveState);

    Boolean delFlow(List<Long> sourceIds, String billTypeCode);

}

==> ejc-assistrmat-impl-3.0.0-20221222.081625-330-sources.jar: com/ejianc/business/assist/rmat/service/IRmatFlowService.java <==
package com.ejianc.business.assist.rmat.service;

import com.ejianc.business.assist.rmat.bean.*;
import com.ejianc.business.assist.rmat.vo.RmatFlowVO;
import com.ejianc.business.outrmat.delivery.bean.OutRmatDeliveryEntity;
import com.ejianc.business.outrmat.lose.bean.OutRmatLoseEntity;
import com.ejianc.business.outrmat.restitute.bean.OutRmatRestituteEntity;
import com.ejianc.business.outrmat.start.bean.OutRmatStartEntity;
import com.ejianc.business.outrmat.stop.bean.OutRmatStopEntity;
import com.ejianc.framework.skeleton.template.IBaseService;

import java.util.List;

/**
 * 租赁流水表
 * 
 * @author generator
 * 
 */
public interface IRmatFlowService extends IBaseService<RmatFlowEntity> {

    Boolean insertFlow(List<RmatFlowVO> vos);

    Boolean insertCheckFlow(CheckEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertCheckFlow(OutRmatDeliveryEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertStopFlow(StopEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertOutRmatStopFlow(OutRmatStopEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertStartFlow(StartEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertOutRmatStartFlow(OutRmatStartEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertRestFlow(RestituteEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertRestFlow(OutRmatRestituteEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertLoseFlow(LoseEntity entity, String billTypeCode, Integer effectiveState);

    Boolean insertLoseFlow(OutRmatLoseEntity entity, String billTypeCode, Integer effectiveState);

    Boolean delFlow(List<Long> sourceIds, String billTypeCode);

}
